aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/mem.rs
diff options
context:
space:
mode:
Diffstat (limited to 'components/script/mem.rs')
-rw-r--r--components/script/mem.rs16
1 files changed, 10 insertions, 6 deletions
diff --git a/components/script/mem.rs b/components/script/mem.rs
index b40a78ec569..47491359a6d 100644
--- a/components/script/mem.rs
+++ b/components/script/mem.rs
@@ -6,24 +6,28 @@
use dom::bindings::conversions::get_dom_class;
use dom::bindings::reflector::DomObject;
-use heapsize::{HeapSizeOf, heap_size_of};
+use malloc_size_of::{MallocSizeOf, MallocSizeOfOps};
use std::os::raw::c_void;
// This is equivalent to measuring a Box<T>, except that DOM objects lose their
// associated box in order to stash their pointers in a reserved slot of their
// JS reflector.
#[allow(unsafe_code)]
-pub fn heap_size_of_self_and_children<T: DomObject + HeapSizeOf>(obj: &T) -> usize {
+pub fn malloc_size_of_including_self<T: DomObject + MallocSizeOf>(
+ ops: &mut MallocSizeOfOps, obj: &T) -> usize
+{
unsafe {
let class = get_dom_class(obj.reflector().get_jsobject().get()).unwrap();
- (class.heap_size_of)(obj as *const T as *const c_void)
+ (class.malloc_size_of)(ops, obj as *const T as *const c_void)
}
}
/// Used by codegen to include the pointer to the `HeapSizeOf` implementation of each
/// IDL interface. This way we don't have to find the most-derived interface of DOM
/// objects by hand in code.
#[allow(unsafe_code)]
-pub unsafe fn heap_size_of_raw_self_and_children<T: HeapSizeOf>(obj: *const c_void) -> usize {
- heap_size_of(obj) + (*(obj as *const T)).heap_size_of_children()
+pub unsafe fn malloc_size_of_including_raw_self<T: MallocSizeOf>(
+ ops: &mut MallocSizeOfOps, obj: *const c_void) -> usize
+{
+ ops.malloc_size_of(obj) + (*(obj as *const T)).size_of(ops)
}
@@ -6,24 +6,28 @@
}
}
-/// Used by codegen to include the pointer to the `HeapSizeOf` implementation of each
+/// Used by codegen to include the pointer to the `MallocSizeOf` implementation of each
/// IDL interface. This way we don't have to find the most-derived interface of DOM
/// objects by hand in code.